function makeInput(mCase,D,z,T,phi,gamma,pileE,pileNu,nNode,H)
% creates OpenSees input file for lateral spreading pile analysis

% convert input friction angle to radians
phi = phi*pi/180;

% obtain p-y curve parameters
[pu,y50,d,mPro] = mDataSort(D,z,T,H,phi,gamma,nNode);

% create file with the appropriate information for PySimple1 material
mTcl = '.tcl';
mFile = strcat(mCase,mTcl);
mDir = mCase;

% create directory for analysis
addpath(pwd)
eval(sprintf('mkdir %s',mDir));
eval(sprintf('cd %s',mDir));
fid = fopen(mFile,'w');

% begin input file generation
fprintf(fid,'################################################################\n');
fprintf(fid,'#                                                              #\n');
fprintf(fid,'# p-y spring and beam model for lateral spreading analysis the #\n');
fprintf(fid,'# p-y curve parameters have been reduced to account for the    #\n');
fprintf(fid,'# presence of the weaker liquefied layer                       #\n');
fprintf(fid,'#                                                              #\n');
fprintf(fid,'# Pile parameters:  D =%4.5g, E =%6.5g, nu =%6.5g             #\n',D,pileE,pileNu);
fprintf(fid,'# Soil parameters:  z =%4.5g, T =%4.5g, phi =%4.5g, gamma =%4.5g   #\n',z,T,phi*180/pi,gamma);
fprintf(fid,'#                                                              #\n');
fprintf(fid,'# Created By:  Chris McGann                                    #\n');
fprintf(fid,'#              Pedro Arduino                                   #\n');
fprintf(fid,'#            --University of Washington--                      #\n');
fprintf(fid,'#                                                              #\n');
fprintf(fid,'# ---> Basic units are kN and m                                #\n');
fprintf(fid,'#                                                              #\n');
fprintf(fid,'################################################################\n\n');
fprintf(fid,'wipe\n\n');
fprintf(fid,'#-----------------------------------------------------------------------------------------\n');
fprintf(fid,'#  1. CREATE P-Y SPRING NODES AND BOUNDARY CONDITIONS\n');
fprintf(fid,'#-----------------------------------------------------------------------------------------\n');
fprintf(fid,'model BasicBuilder -ndm 3 -ndf 3\n\n');

fprintf(fid,'# nodes for soil end of the spring\n');
for k = 2:nNode
    fprintf(fid,'node %i  0.000 0.000 %6.5f\n',k,d(k));
end
fprintf(fid,'\n# nodes for pile end of the spring\n');
for k = 2:nNode
    fprintf(fid,'node %i  0.000 0.000 %6.5f\n',k+200,d(k));
end
fprintf(fid,'puts "Finshed creating all p-y spring nodes..."\n\n');

fprintf(fid,'# define fixities for the soil end of springs\n');
for k = 2:nNode
    fprintf(fid,'fix %i 1 1 1\n',k);
end
fprintf(fid,'\n# define fixities for pile end of springs\n');
for k = 2:nNode
    fprintf(fid,'fix %i 0 1 1\n',k+200);
end
fprintf(fid,'puts "Finished creating all p-y spring boundary conditions..."\n\n');

fprintf(fid,'#-----------------------------------------------------------------------------------------\n');
fprintf(fid,'#  2. CREATE P-Y SPRING MATERIAL\n');
fprintf(fid,'#-----------------------------------------------------------------------------------------\n\n');

for k = 2:nNode
    fprintf(fid,'uniaxialMaterial PySimple1 %i 2 %12.5f %12.5f 0\n',k,pu(k),y50(k));
end
fprintf(fid,'puts "Finished creating all p-y spring materials..."\n\n');

fprintf(fid,'#-----------------------------------------------------------------------------------------\n');
fprintf(fid,'#  3. CREATE P-Y SPRING ELEMENTS\n');
fprintf(fid,'#-----------------------------------------------------------------------------------------\n\n');

for k = 2:nNode
    fprintf(fid,'element zeroLength %i %i %i -mat %i -dir 1\n',k,k,k+200,k);
end
fprintf(fid,'puts "Finished creating all p-y spring elements..."\n\n');

fprintf(fid,'#-----------------------------------------------------------------------------------------\n');
fprintf(fid,'#  4. CREATE PILE NODES AND BOUNDARY CONDITIONS\n');
fprintf(fid,'#-----------------------------------------------------------------------------------------\n');
fprintf(fid,'model BasicBuilder -ndm 3 -ndf 6\n\n');

fprintf(fid,'# create nodes\n');
for k = 1:nNode
    fprintf(fid,'node %i  0.000 0.000 %6.5f\n',k+500,d(k));
end

fprintf(fid,'\nset nodesInfo6 [open NodesInfo6.dat w]\n');
for k = 1:nNode
    fprintf(fid,'puts $nodesInfo6 "%i 0 0 %6.5f"\n',k+500,d(k));
end
fprintf(fid,'close $nodesInfo6\nputs "Finished creating all pile nodes..."\n\n');

fprintf(fid,'# create geometric transformation for vertical pile\n');
fprintf(fid,'set transTag 1\n');
fprintf(fid,'geomTransf Linear $transTag  0 -1 0\n\n');

fprintf(fid,'# create the fixities for the pile nodes\n');
for k = 1:nNode-1
    fprintf(fid,'fix %i  0 1 0 1 0 1\n',k+500);
end
fprintf(fid,'fix %i  0 1 1 1 0 1\n',nNode+500);
fprintf(fid,'puts "Finished creating all pile boundary conditions..."\n\n');

fprintf(fid,'# define equalDOF for pile and spring nodes\n');
for k = 2:nNode
    fprintf(fid,'equalDOF %i %i 1\n',k+500,k+200);
end
fprintf(fid,'puts "Finished creating all pile-spring equalDOF..."\n\n');

fprintf(fid,'#-----------------------------------------------------------------------------------------\n');
fprintf(fid,'#  5. CREATE ELASTIC PILE SECTION\n');
fprintf(fid,'#-----------------------------------------------------------------------------------------\n\n');

fprintf(fid,'# pile properties\n');
fprintf(fid,'set pi       [expr 4.0*atan(1.0)]\n');
fprintf(fid,'set radius   %4.5f\n',D/2);
fprintf(fid,'set area     [expr $pi*$radius*$radius]\n');
fprintf(fid,'set I        [expr $pi*$radius*$radius*$radius*$radius/4.0]\n');
fprintf(fid,'set J        [expr 2.0*$I]\n');
fprintf(fid,'set E        %6.5f\n',pileE);
fprintf(fid,'set nu       %6.5f\n',pileNu);
fprintf(fid,'set G        [expr $E/(2.0*(1.0+$nu))]\n');
fprintf(fid,'set nIntPts  3\n');
fprintf(fid,'set secTag   1\n');
fprintf(fid,'set secTag3D 3\n\n');

fprintf(fid,'# beam section, no torsion\n');
fprintf(fid,'section Elastic  $secTag $E $area $I $I $G $J\n');
fprintf(fid,'# create torsional section\n');
fprintf(fid,'uniaxialMaterial Elastic 100 1.e10\n');
fprintf(fid,'# aggregate the beam section\n');
fprintf(fid,'section Aggregator $secTag3D  100 T -section $secTag\n');
fprintf(fid,'puts "Finished creating all beam materials..."\n\n');

fprintf(fid,'#-----------------------------------------------------------------------------------------\n');
fprintf(fid,'#  6. CREATE PILE ELEMENTS\n');
fprintf(fid,'#-----------------------------------------------------------------------------------------\n\n');

for k = 1:nNode-1
    fprintf(fid,'element dispBeamColumn %i %i %i $nIntPts $secTag3D $transTag\n',500+k,500+k,k+501);
end

fprintf(fid,'\nset pileInfo [open PileInfo.dat w]\n');
for k = 1:nNode-1
    fprintf(fid,'puts $pileInfo "%i %i %i"\n',500+k,500+k,k+501);
end
fprintf(fid,'close $pileInfo\n');
fprintf(fid,'puts "Finished creating all beam elements..."\n\n');

fprintf(fid,'#-----------------------------------------------------------------------------------------\n');
fprintf(fid,'#  7. CREATE RECORDERS\n');
fprintf(fid,'#-----------------------------------------------------------------------------------------\n\n');

fprintf(fid,'# create list with pile node info\nset nodeList6 {}\n');
fprintf(fid,'set channel [open "NodesInfo6.dat" r]\nset ctr 0;\n');
fprintf(fid,'foreach line [split [read -nonewline $channel] \\n] {\n');
fprintf(fid,'set ctr0 [expr $ctr+1];\nset lineData($ctr) $line\n');
fprintf(fid,'set nodeNumber [lindex $lineData($ctr) 0]\nlappend nodeList6 $nodeNumber\n}\n');
fprintf(fid,'close $channel\n\n');

fprintf(fid,'# create pile element list\nset BeamElementList {}\n');
fprintf(fid,'set channel [open "PileInfo.dat" r]\nset ctr 0;\n');
fprintf(fid,'foreach line [split [read -nonewline $channel] \\n] {\n');
fprintf(fid,'set ctr0 [expr $ctr+1];\nset lineData($ctr) $line\n');
fprintf(fid,'set elementNumber [lindex $lineData($ctr) 0]\nlappend BeamElementList $elementNumber\n');  
fprintf(fid,'}\nclose $channel\n\n');

fprintf(fid,'# designate recorder timestep\n');
fprintf(fid,'set dt 0.5\n\n');
fprintf(fid,'recorder Node -file pyDisplace.out -time -nodeRange 202 %i -dof 1 -dT $dt disp\n',nNode+200);
fprintf(fid,'recorder Node -file pyForces.out   -time -nodeRange 2   %i -dof 1 -dT $dt reaction\n\n',nNode);
fprintf(fid,'eval "recorder Node -file Displacements.out -time -node $nodeList6 -dof 1 2 3 -dT $dt disp"\n');
fprintf(fid,'eval "recorder Node -file Reaction.out      -time -node $nodeList6 -dof 1 2 3 -dT $dt reaction "\n');
fprintf(fid,'eval "recorder Element -file globalForces.out    -time -ele $BeamElementList -dT $dt globalForce"\n\n');

fprintf(fid,'#-----------------------------------------------------------------------------------------\n');
fprintf(fid,'#  8. CREATE APPLIED DISPLACEMENT PROFILE\n');
fprintf(fid,'#-----------------------------------------------------------------------------------------\n\n');

fprintf(fid,'pattern Plain 10 {Series -time {0 10 10000} -values {0 1 1} -factor 1} {\n');
for k = 2:length(mPro)
    fprintf(fid,'    sp %i 1 %6.3f\n',k,mPro(k));
end
fprintf(fid,'}\nputs "Finished adding all sp constraints for push-over analysis..."\n\n');

fprintf(fid,'#-----------------------------------------------------------------------------------------\n');
fprintf(fid,'#  8. CREATE AND EXECUTE THE ANALYSIS\n');
fprintf(fid,'#-----------------------------------------------------------------------------------------\n\n');

fprintf(fid,'integrator  LoadControl 0.05\n');
fprintf(fid,'numberer    RCM\n');
fprintf(fid,'system      BandGeneral\n');
fprintf(fid,'constraints Transformation\n');
fprintf(fid,'test        NormDispIncr 1e-5 20 1\n');
fprintf(fid,'algorithm   Newton\n');
fprintf(fid,'analysis    Static\n\n');

fprintf(fid,'set startT [clock seconds]\n\n');
fprintf(fid,'analyze     205\n\n');
fprintf(fid,'set endT [clock seconds]\n\n');

fprintf(fid,'puts "Load Application finished..."\n');
fprintf(fid,'puts "Analysis execution time: [expr $endT-$startT] seconds"\n\n');

fprintf(fid,'wipe');

fclose(fid);
cd ..
rmpath(pwd);

return
